Class: CryptoApis::MetadataApi

Inherits:
Object
  • Object
show all
Defined in:
lib/crypto_apis/api/metadata_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ MetadataApi



19
20
21
# File 'lib/crypto_apis/api/metadata_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/crypto_apis/api/metadata_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#list_supported_assets(opts = {}) ⇒ ListSupportedAssetsR

List Supported Assets This endpoint will return a list of supported assets. The asset could be a cryptocurrency or FIAT assets that we support. Each asset has a unique identifier - assetId and a unique symbol in the form of a string, e.g. \“BTC\”.

Options Hash (opts):

  • :context (String)

    In batch situations the user can use the context to correlate responses with requests. This property is present regardless of whether the response was successful or returned as an error. `context` is specified by the user.

  • :asset_type (String)

    Defines the type of the supported asset. This could be either \"crypto\" or \"fiat\".

  • :limit (Integer)

    Defines how many items should be returned in the response per page basis. (default to 50)

  • :offset (Integer)

    The starting index of the response items, i.e. where the response should start listing the returned items. (default to 0)



30
31
32
33
# File 'lib/crypto_apis/api/metadata_api.rb', line 30

def list_supported_assets(opts = {})
  data, _status_code, _headers = list_supported_assets_with_http_info(opts)
  data
end

#list_supported_assets_with_http_info(opts = {}) ⇒ Array<(ListSupportedAssetsR, Integer, Hash)>

List Supported Assets This endpoint will return a list of supported assets. The asset could be a cryptocurrency or FIAT assets that we support. Each asset has a unique identifier - &#x60;assetId&#x60; and a unique symbol in the form of a string, e.g. \&quot;BTC\&quot;.

Options Hash (opts):

  • :context (String)

    In batch situations the user can use the context to correlate responses with requests. This property is present regardless of whether the response was successful or returned as an error. &#x60;context&#x60; is specified by the user.

  • :asset_type (String)

    Defines the type of the supported asset. This could be either \&quot;crypto\&quot; or \&quot;fiat\&quot;.

  • :limit (Integer)

    Defines how many items should be returned in the response per page basis. (default to 50)

  • :offset (Integer)

    The starting index of the response items, i.e. where the response should start listing the returned items. (default to 0)



43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/crypto_apis/api/metadata_api.rb', line 43

def list_supported_assets_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: MetadataApi.list_supported_assets ...'
  end
  allowable_values = ["fiat", "crypto"]
  if @api_client.config.client_side_validation && opts[:'asset_type'] && !allowable_values.include?(opts[:'asset_type'])
    fail ArgumentError, "invalid value for \"asset_type\", must be one of #{allowable_values}"
  end
  # resource path
  local_var_path = '/market-data/assets/supported'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'context'] = opts[:'context'] if !opts[:'context'].nil?
  query_params[:'assetType'] = opts[:'asset_type'] if !opts[:'asset_type'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ListSupportedAssetsR'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKey']

  new_options = opts.merge(
    :operation => :"MetadataApi.list_supported_assets",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: MetadataApi#list_supported_assets\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end